Learn R Programming

gsalib (version 2.2.1)

gsalib-package: Utility functions for GATK

Description

Utility functions for analysis of genome sequence data with the GATK

Arguments

Author

Kiran Garimella

Maintainer: Louis Bergelson <louisb@broadinstitute.org>

Details

Package:gsalib
Type:Package
Version:2.2
Date:2015-03-17
License:MIT
LazyLoad:yes

This package is primarily meant to be used programmatically by GATK tools. However the gsa.read.gatkreport() function can be used to easily read in data from a GATKReport. A GATKReport is a multi-table document generated by GATK tools.

References

https://gatk.broadinstitute.org/hc/en-us/articles/360035532172-GATKReport-and-gsalib

Examples

Run this code
test_file = system.file("inst", "extdata", "test_gatkreport.table", package = "gsalib");
report = gsa.read.gatkreport(test_file);

Run the code above in your browser using DataLab