Utility functions for analysis of genome sequence data with the GATK
Arguments
Author
Kiran Garimella
Maintainer: Louis Bergelson <louisb@broadinstitute.org>
Details
Package:
gsalib
Type:
Package
Version:
2.2
Date:
2015-03-17
License:
MIT
LazyLoad:
yes
This package is primarily meant to be used programmatically by GATK tools. However the gsa.read.gatkreport() function can be used to easily read in data from a GATKReport. A GATKReport is a multi-table document generated by GATK tools.